has_project

Function has_project 

pub fn has_project() -> CtResult<Option<String>>
Is there a project running currently? Meaning, is it stored as a reference in the persistent store? If one exists, the project name is returned This already checks, if the project stored in the persistent store exists