stored_except

Function stored_except 

pub fn stored_except(name: &str) -> CtResult<Option<String>>
Stop every project that might be stored in the persistant store, except the one specified

Returns

Returns Some(name) with the name of the stopped project, if one was stopped, otherwise it returns None